..
  class.rst

ardt.datasets.ascertain.AscertainTrial
======================================

.. currentmodule:: ardt.datasets.ascertain

.. autoclass:: AscertainTrial
    :members:
    :show-inheritance:
    :inherited-members:
